package com.example.attendance

import android.content.Intent
import android.graphics.Bitmap
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.provider.MediaStore
import android.view.View
import android.widget.Button
import android.widget.ImageView
import android.widget.Toast
import androidx.appcompat.app.AlertDialog
import com.google.android.material.textfield.TextInputEditText
import com.google.firebase.auth.FirebaseAuth
import com.google.firebase.auth.ktx.auth
import com.google.firebase.database.DatabaseReference
import com.google.firebase.database.FirebaseDatabase
import com.google.firebase.ktx.Firebase

class RegisterActivity : AppCompatActivity() {
    private lateinit var edt_email: TextInputEditText
    private lateinit var edt_pass: TextInputEditText
    private lateinit var edt_usrname: TextInputEditText
    private lateinit var edt_phone: TextInputEditText
    private lateinit var edt_conPass: TextInputEditText
    private lateinit var btn_register: Button
    private lateinit var profile_image: ImageView

    lateinit var email: String
    lateinit var usrname: String
    lateinit var phone: String
    lateinit var pass: String
    lateinit var conpass: String

    // For firebase implementation
    private lateinit var auth: FirebaseAuth
    private lateinit var database: DatabaseReference


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_register)

        edt_email = findViewById(R.id.edt_email)
        edt_pass = findViewById(R.id.edt_pass)
        edt_usrname = findViewById(R.id.edt_usrname)
        edt_phone = findViewById(R.id.edt_phone)
        edt_conPass = findViewById(R.id.edt_conPass)
        btn_register = findViewById(R.id.btn_register)
        profile_image = findViewById(R.id.profile_image)

        auth = FirebaseAuth.getInstance()

        btn_register.setOnClickListener{
            val db = DBHelper(this, null)
            email = edt_email.text.toString()
            pass = edt_pass.text.toString()
            conpass = edt_conPass.text.toString()
            usrname = edt_usrname.text.toString()
            phone = edt_phone.text.toString()

            signUpUser()
            database = FirebaseDatabase.getInstance().getReference("UserInfo")
            val userInfo = UserInfo(email,usrname,phone, pass)
            database.child(usrname).setValue(userInfo).addOnSuccessListener {
                edt_email.text?.clear()
                edt_usrname.text?.clear()
                edt_phone.text?.clear()
                edt_pass.text?.clear()
                edt_conPass.text?.clear()
            }.addOnFailureListener{
                Toast.makeText(this, "Failed", Toast.LENGTH_LONG).show()
            }
            db.addUser(email,usrname,phone,pass,conpass)
            Toast.makeText(this, email + " added to database", Toast.LENGTH_LONG).show()

        }

        profile_image.setOnClickListener(View.OnClickListener { v: View? ->
            // Create the camera_intent ACTION_IMAGE_CAPTURE it will open the camera for capture the image
            val cameraIntent = Intent(MediaStore.ACTION_IMAGE_CAPTURE)
            // Start the activity with camera_intent, and request pic id
            startActivityForResult(cameraIntent, pic_id)
        })


    }


    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        // Match the request 'pic id with requestCode
        if (requestCode == pic_id) {
            // BitMap is data structure of image file which store the image in memory
            val photo = data!!.extras!!["data"] as Bitmap?
            // Set the image in imageview for display
            profile_image.setImageBitmap(photo)
        }
    }
    companion object {
        // Define the pic id
        private const val pic_id = 123
    }

    private fun signUpUser() {


        // check pass
        if (email.isBlank() || pass.isBlank() || conpass.isBlank()) {
            Toast.makeText(this, "Email and Password can't be blank", Toast.LENGTH_SHORT).show()
            return
        }
        

        if (pass != conpass) {
            Toast.makeText(this, "Password and Confirm Password do not match", Toast.LENGTH_SHORT)
                .show()
            return
        }
        if(pass.length<8){
            Toast.makeText(this, "Password should atleast have 8 characters", Toast.LENGTH_SHORT)
                .show()
            return
        }
        if(!pass.contains("#") || !pass.contains("&") || !pass.contains("@")){
            Toast.makeText(this, "Password should special characters", Toast.LENGTH_SHORT)
                .show()
            return
        }


        // If all credential are correct
        // We call createUserWithEmailAndPassword
        // using auth object and pass the
        // email and pass in it.
        auth.createUserWithEmailAndPassword(email, pass).addOnCompleteListener(this) {
            if (it.isSuccessful) {
                moveToLogin()
                Toast.makeText(this, "Successfully signed Up", Toast.LENGTH_SHORT).show()
                finish()
            } else {
                showAlert()
                Toast.makeText(this, it.exception.toString(), Toast.LENGTH_SHORT).show()
            }
            System.out.println("error: " + it.exception.toString())
        }

    }

    private fun moveToLogin(){
        val intent = Intent(this, LoginActivity::class.java)
        startActivity(intent)
    }

    private fun showAlert(){
        val builder = AlertDialog.Builder(this)
        //set title for alert dialog
        builder.setTitle("Warning")
        //set message for alert dialog
        builder.setMessage("Unsuccessfull attempt")
        builder.setIcon(android.R.drawable.ic_dialog_alert)

        //performing positive action
        builder.setPositiveButton("Try again"){dialogInterface, which ->

        }
        // Create the AlertDialog
        val alertDialog: AlertDialog = builder.create()
        // Set other dialog properties
        alertDialog.setCancelable(false)
        alertDialog.show()
    }
}